"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _Button = _interopRequireDefault(require("../Button"));

var _RequestHeader = require("../../models/RequestHeader");

var _styles = require("./styles");

var _tsJsonObject = require("ts-json-object");

var _core = require("@emotion/core");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function buildRequestHeadersFromJson(jsonObj) {
  var headerArray = [];

  for (var entry in jsonObj) {
    var reqHeader = new _RequestHeader.RequestHeader(entry, jsonObj[entry]);
    headerArray.push(reqHeader);
  }

  return headerArray;
}

function isJsonValid(jsonString) {
  try {
    JSON.parse(jsonString);
  } catch (e) {
    console.error(e);
    return false;
  }

  return true;
}

async function loadRequestHeaders(context, storeKey) {
  const storedSchemaRequestHeaderString = await context.store.getItem(storeKey);
  return JSON.parse(storedSchemaRequestHeaderString);
}

const Configuration = ({
  insomniaContext
}) => {
  const [schemaRequestHeaders, setSchemaRequestHeaders] = (0, _react.useState)('');
  const [defaultRequestHeaders, setDefaultRequestHeaders] = (0, _react.useState)('');
  (0, _react.useEffect)(() => {
    async function load() {
      let schemaHeadersJson = new _tsJsonObject.JSONObject();
      (await loadRequestHeaders(insomniaContext, 'gql-gen:schemaRequestHeaders')).forEach(header => {
        schemaHeadersJson[header.name] = header.value;
      });
      let defaultHeadersJson = new _tsJsonObject.JSONObject();
      (await loadRequestHeaders(insomniaContext, 'gql-gen:defaultRequestHeaders')).forEach(header => {
        defaultHeadersJson[header.name] = header.value;
      });
      setSchemaRequestHeaders(JSON.stringify(schemaHeadersJson));
      setDefaultRequestHeaders(JSON.stringify(defaultHeadersJson));
    }

    load();
  }, []);

  const handleSchemaHeadersChange = event => {
    if (isJsonValid(event.target.value) === false) {
      event.target.setCustomValidity("Invalid JSON");
      event.target.reportValidity();
    } else {
      event.target.setCustomValidity("");
    }

    setSchemaRequestHeaders(event.target.value);
  };

  const handleDefaultHeadersChange = event => {
    if (isJsonValid(event.target.value) === false) {
      event.target.setCustomValidity("Invalid JSON");
      event.target.reportValidity();
    } else {
      event.target.setCustomValidity("");
    }

    setDefaultRequestHeaders(event.target.value);
  };

  const handleSave = (0, _react.useCallback)(() => {
    async function execute() {
      var schemaRequestHeaderObjs = buildRequestHeadersFromJson(JSON.parse(schemaRequestHeaders));
      var defaultRequestHeaderObjs = buildRequestHeadersFromJson(JSON.parse(defaultRequestHeaders));
      await insomniaContext.store.setItem('gql-gen:schemaRequestHeaders', JSON.stringify(schemaRequestHeaderObjs));
      await insomniaContext.store.setItem('gql-gen:defaultRequestHeaders', JSON.stringify(defaultRequestHeaderObjs));
    }

    execute();
  }, [schemaRequestHeaders, defaultRequestHeaders]);
  return (0, _core.jsx)("form", null, (0, _core.jsx)("div", {
    className: "form-control form-control--outlined"
  }, (0, _core.jsx)("label", null, "Schema Query Request Headers", (0, _core.jsx)("textarea", {
    value: schemaRequestHeaders,
    rows: 10,
    placeholder: "{}",
    onChange: event => handleSchemaHeadersChange(event)
  })), (0, _core.jsx)("label", null, "Default Query Request Headers", (0, _core.jsx)("textarea", {
    value: defaultRequestHeaders,
    rows: 10,
    placeholder: "{}",
    onChange: event => handleDefaultHeadersChange(event)
  }))), (0, _core.jsx)("div", {
    css: _styles.actionsContainerStyle
  }, (0, _core.jsx)(_Button.default, {
    label: "Cancel",
    closeModal: true
  }), (0, _core.jsx)(_Button.default, {
    label: "Save",
    onClick: handleSave,
    closeModal: true
  })));
};

var _default = Configuration;
exports.default = _default;